########
 setux
########

**Setup Tux**

Install, Deploy, Admin

========
Abstract
========

Although Setux comes with a rudimentary REPL, which may prove useful, it's mainly intended to be used as a Python framework.

=====
Usage
=====

REPL:
.. code-block:: shell

    setux

Python:
.. code-block:: python

   import setux

============
Installation
============

.. code-block:: shell 

    $ pip install setux
